Django-MySQL Documentation
==========================

.. figure:: https://raw.github.com/adamchainz/django-mysql/master/docs/images/dolphin-pony.png
   :alt: The dolphin-pony - proof that cute + cute = double cute.

Django-MySQL is a non-inventively named package that helps you use some
MySQL/MariaDB-specific features in the world of Django.

If you're new, check out the :doc:`exposition` to see all the features in
action, or get started with :doc:`installation`. Otherwise, take your pick:

.. toctree::
   :maxdepth: 2

   exposition
   installation
   queryset_extensions
   model_fields
   field_lookups
   aggregates
   database_functions
   migration_operations
   form_fields
   validators
   cache
   locks
   status
   manage_commands
   utilities
   test_utilities
   monkey_patches
   exceptions
   contributing
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
